﻿/***********************************************************************************
* PROJECT: ASP_NET_check_db_oracle                                                 *
* AUTHOR: Alan Pipitone                                                            *
* DATE: 22/05/2012                                                                 *
* WEBSITE: http://www.alan-pipitone.com/                                           *
*                                                                                  *
* NB: This software has no warranty                                                *
************************************************************************************/
using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using System.Globalization;

namespace ASP_NET_check_db_oracle
{
    class Program
    {
        static void Main(string[] args)
        {
            string appName = "";
            double warning = 0;
            double critical = 0;

            bool arg_app_present = false;
            bool arg_w_present = false;
            bool arg_c_present = false;

            string performanceData = "";
            try
            {
                //read the arguments
                for (int i = 0; i < args.Length; i++)
                {
                    switch (args[i])
                    {
                        case "/a":
                            if (args.Length > i + 1)
                            {
                                //save application name
                                appName = args[++i];
                                arg_app_present = true;
                            }
                            else
                            {
                                Console.WriteLine("ERROR in parsing argument /a: missing value");
                                Environment.Exit(2);
                            }
                            break;
                        case "/w":
                            if (args.Length > i + 1)
                            {
                                //save warning value
                                warning = Convert.ToDouble(args[++i], CultureInfo.InvariantCulture);
                                arg_w_present = true;
                            }
                            else
                            {
                                Console.WriteLine("ERROR in parsing argument /w: missing value");
                                Environment.Exit(2);
                            }
                            break;
                        case "/c":
                            if (args.Length > i + 1)
                            {
                                //save critical value
                                critical = Convert.ToDouble(args[++i], CultureInfo.InvariantCulture);
                                arg_c_present = true;
                            }
                            else
                            {
                                Console.WriteLine("ERROR in parsing argument /c: missing value");
                                Environment.Exit(2);
                            }
                            break;
                        case "/h":
                            //print the help
                            help();
                            Environment.Exit(3);
                            break;
                        default:
                            //invalid argument
                            Console.WriteLine("ERROR: argument " + args[i] + " isn't valid, type ASP_NET_check_db_oracle.exe /h for the help");
                            Environment.Exit(3);
                            break;
                    }
                }

                //check if we have the application name
                if (arg_app_present == false)
                {
                    Console.WriteLine("error: /a is a mandatory argument, type ASP_NET_check_db_oracle.exe /h for the help");
                    Environment.Exit(2);
                }

                //read the xml configuration file
                ReadConfig config = new ReadConfig(appName);

                //init the db
                CheckDataBase dataBase = new CheckDataBase(config.getConnectionString());

                //do the query and save the performance
                TimeSpan performance = dataBase.getPerformance(config.getQuery());

                //get the datasource
                string datasource = dataBase.getDataSource().Replace("\r\n","").Replace("\n","").Replace("\t","").Replace("  ","");

                //if critical and warning are present check the Threshold
                if (arg_w_present & arg_c_present)
                {
                    //set the performance data string
                    performanceData = "|time=" + performance.TotalSeconds + "s;" + warning + ";" + critical + ";;";

                    if (performance.TotalSeconds >= critical)
                    {
                        Console.WriteLine("time elapsed: " + String.Format("{0:0.000}", performance.TotalSeconds) + " sec. >> DataSource is " + datasource + performanceData);
                        Environment.Exit(2);
                    }
                    else if (performance.TotalSeconds >= warning)
                    {
                        Console.WriteLine("time elapsed: " + String.Format("{0:0.000}", performance.TotalSeconds) + " sec. >> DataSource is " + datasource + performanceData);
                        Environment.Exit(1);
                    }
                }
                else
                {
                    //set the performance data string
                    performanceData = "|time=" + performance.TotalSeconds + "s";
                }

                //print the performance
                Console.WriteLine("time elapsed: " + String.Format("{0:0.000}", performance.TotalSeconds) + " sec. >> DataSource is " + datasource + performanceData);
                Environment.Exit(0);

            }
            catch (Exception ex)
            {
                //print the exception
                Console.WriteLine("Error in main program: " + ex.Message);
                Environment.Exit(2);
            }
        }

        static void help()
        {
            ///a ares /w 2.5 /c 5.6
            string help = "AUTHOR: Alan Pipitone\n\n";
            help = help + "WEBSITE: http://www.alan-pipitone.com/\n\n";
            help = help + "Arguments of ASP_NET_check_db_oracle:\n\n";
            help = help + "              /a <application name>\n";
            help = help + "              [/w <warning value>]\n";
            help = help + "              [/c <critical value>]\n\n";
            help = help + "/a  here you have to insert the name of the  application that\n";
            help = help + "    you've set into the configuration file of this script.\n";
            help = help + "    To create it see the example at the bottom.\n";
            help = help + "\n";
            help = help + "/w  here you have to insert the value (in seconds) of the \n";
            help = help + "    warning level for the execution of the query.\n";
            help = help + "    Optional argument.\n";
            help = help + "\n";
            help = help + "/c  here you have to insert the value (in seconds) of the \n";
            help = help + "    critical level for the execution of the query.\n";
            help = help + "    Optional argument.\n";
            help = help + "\n";
            help = help + "Example:\n";
            help = help + "\n";
            help = help + "Into the directory of this script you have to create an xml\n";
            help = help + "(ASP_NET_check_db_oracle.xml) that contains the properties\n";
            help = help + "of your ASP .Net applications.\n";
            help = help + "For example:";
            help = help + "\n\n";
            help = help + "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
            help = help + " <config>\n";
	        help = help + "  <application name=\"myApp1\">\n";
            help = help + "   <!-- insert the path of the web.config of your Asp. Net app -->\n";
		    help = help + "   <web.config>C:\\inetpub\\wwwroot\\myapp1\\Web.config</web.config>\n";
            help = help + "   <!-- insert the connection string name that is present\n";
            help = help + "        into the web.config of your Asp .Net app -->\n";
		    help = help + "   <connection.string>connStringName</connection.string>\n";
            help = help + "   <!-- insert the query to check the connectivity -->\n";
            help = help + "   <query>SELECT * FROM myTable1</query>\n";
	        help = help + "  </application>\n";
            help = help + "  <!-- insert here other application nodes if you want to check\n";
            help = help + "       other Asp .Net applications on the IIS Web server -->\n";
            help = help + " </config>\n\n";
            help = help + "Now, if we want to check myApp1 we have to run the plug-in\n";
            help = help + "as below:\n\n";
            help = help + "ASP_NET_check_db_oracle.exe /a myApp1 /w 2.5 /c 5\n\n";
            help = help + "or\n\n";
            help = help + "ASP_NET_check_db_oracle.exe /a myApp1\n";
            help = help + "If you don't want add warning or critical thresholds.";

            Console.WriteLine(help);
        }
    }
}