﻿/***********************************************************************************
* PROJECT: ASP_NET_check_db_oracle                                                 *
* AUTHOR: Alan Pipitone                                                            *
* DATE: 22/05/2012                                                                 *
* WEBSITE: http://www.alan-pipitone.com/                                           *
*                                                                                  *
* NB: This software has no warranty                                                *
************************************************************************************/
using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Configuration;

namespace ASP_NET_check_db_oracle
{
    class ReadConfig
    {

        private string webConfig = "";
        private string connectionString = "";
        private string query = "";

        public ReadConfig(string appName)
        {
            try
            {
                //get the current directory of this script
                System.Reflection.Assembly a = System.Reflection.Assembly.GetExecutingAssembly();

                //save the directory
                string homeDirectory = System.IO.Path.GetDirectoryName(a.Location);
                //save the program name
                string programName = System.IO.Path.GetFileNameWithoutExtension(a.Location);

                //load configuration file
                XmlDocument doc = new XmlDocument();
                doc.Load(homeDirectory + "\\" + programName + ".xml");

                //get the web config
                webConfig = doc.SelectSingleNode("/config/application[@name=\"" + appName + "\"]/web.config").InnerText;

                //get the query
                query = doc.SelectSingleNode("/config/application[@name=\"" + appName + "\"]/query").InnerText;

                //get the connection string name
                string connectionStringName = doc.SelectSingleNode("/config/application[@name=\"" + appName + "\"]/connection.string").InnerText;

                // Get the machine.config file.
                ExeConfigurationFileMap fileMap = new ExeConfigurationFileMap();

                //You may want to map to your own web.config file here.
                fileMap.ExeConfigFilename = webConfig;

                System.Configuration.Configuration config =
                    ConfigurationManager.OpenMappedExeConfiguration(fileMap,
                    ConfigurationUserLevel.None);

                //Read all connection string
                foreach (ConnectionStringSettings currentConnStringSetting in config.ConnectionStrings.ConnectionStrings)
                {
                    //save the connection string
                    if (currentConnStringSetting.Name.ToLower() == connectionStringName.ToLower())
                        connectionString = currentConnStringSetting.ConnectionString;

                }

                //check if we found web.config
                if (connectionString == "")
                {
                    //print the exception
                    Console.WriteLine("Error in Web.Config: the connection string " + connectionStringName + " doesn't exist");
                    Environment.Exit(2);
                }
            }
            catch(Exception ex)
            {
                //print the exception
                Console.WriteLine("Error reading xml: " + ex.Message);
                Environment.Exit(2);
            }
        }

        public string getConnectionString()
        {
            return connectionString;
        }

        public string getQuery()
        {
            return query;
        }
    }
}
